#ifndef _PTT_H
#define _PTT_H

extern void init_ptt(const char *path, int inverted, int mode);
extern void set_ptt(int ptt);

#endif
